==================================
``psyclone.psyir.nodes.container``
==================================

.. automodule:: psyclone.psyir.nodes.container

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.container


Classes
=======

- :py:class:`Container`:
  Node representing a set of Routine and/or Container nodes, as well


.. autoclass:: Container
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: Container
      :parts: 1
